@@ -149,6 +149,9 @@ func (m *jsMinifier) minifyStmt(i js.IStmt) {
 	case *js.IfStmt:
 		hasIf := !m.isEmptyStmt(stmt.Body)
 		hasElse := !m.isEmptyStmt(stmt.Else)
+		if !hasIf && !hasElse {
+			break
+		}
 
 		m.write(ifOpenBytes)
 		m.minifyExpr(stmt.Cond, js.OpExpr)
@@ -270,8 +273,8 @@ func (m *jsMinifier) minifyStmt(i js.IStmt) {
 		m.minifyExpr(stmt.Init, js.OpExpr)
 		m.write(closeParenOpenBracketBytes)
 		m.needsSemicolon = false
-		for _, clause := range stmt.List {
-			clause.List = m.optimizeStmtList(clause.List, defaultBlock)
+		for i, _ := range stmt.List {
+			stmt.List[i].List = m.optimizeStmtList(stmt.List[i].List, defaultBlock)
 		}
 		m.renamer.renameScope(stmt.Scope)
 		for _, clause := range stmt.List {
@@ -1054,9 +1057,9 @@ func (m *jsMinifier) minifyExpr(i js.IExpr, prec js.OpPrec) {
 	case *js.ObjectExpr:
 		parentInFor := m.inFor
 		m.inFor = false
-		if m.expectExpr != expectAny {
+		groupedStmt := m.expectExpr != expectAny
+		if groupedStmt {
 			m.write(openParenBracketBytes)
-			m.groupedStmt = true
 		} else {
 			m.write(openBraceBytes)
 		}
@@ -1067,6 +1070,9 @@ func (m *jsMinifier) minifyExpr(i js.IExpr, prec js.OpPrec) {
 			m.minifyProperty(item)
 		}
 		m.write(closeBraceBytes)
+		if groupedStmt {
+			m.groupedStmt = true
+		}
 		m.inFor = parentInFor
 	case *js.TemplateExpr:
 		if expr.Tag != nil {
