@@ -23,7 +23,8 @@ var DefaultMinifier = &Minifier{}
 
 // Minifier is a JSON minifier.
 type Minifier struct {
-	Precision int // number of significant digits
+	Precision   int  // number of significant digits
+	KeepNumbers bool // prevent numbers from being minified
 }
 
 // Minify minifies JSON data, it reads from r and writes to w.
@@ -61,7 +62,7 @@ func (o *Minifier) Minify(_ *minify.M, w io.Writer, r io.Reader, _ map[string]st
 		}
 		skipComma = gt == json.StartObjectGrammar || gt == json.StartArrayGrammar
 
-		if 0 < len(text) && ('0' <= text[0] && text[0] <= '9' || text[0] == '-') {
+		if !o.KeepNumbers && 0 < len(text) && ('0' <= text[0] && text[0] <= '9' || text[0] == '-') {
 			text = minify.Number(text, o.Precision)
 			if text[0] == '.' {
 				w.Write(zeroBytes)
