@@ -2,8 +2,11 @@
 package minify
 
 import (
+	"bytes"
 	"errors"
+	"fmt"
 	"io"
+	"io/ioutil"
 	"log"
 	"mime"
 	"net/http"
@@ -12,6 +15,7 @@ import (
 	"os/exec"
 	"path"
 	"regexp"
+	"strings"
 	"sync"
 
 	"github.com/tdewolff/parse/v2"
@@ -51,12 +55,52 @@ type cmdMinifier struct {
 	cmd *exec.Cmd
 }
 
+var cmdArgExtension = regexp.MustCompile(`^\.[0-9a-zA-Z]+`)
+
 func (c *cmdMinifier) Minify(_ *M, w io.Writer, r io.Reader, _ map[string]string) error {
 	cmd := &exec.Cmd{}
 	*cmd = *c.cmd // concurrency safety
-	cmd.Stdout = w
-	cmd.Stdin = r
-	return cmd.Run()
+
+	var in, out *os.File
+	for i, arg := range cmd.Args {
+		if j := strings.Index(arg, "$in"); j != -1 {
+			var err error
+			ext := cmdArgExtension.FindString(arg[j+3:])
+			if in, err = ioutil.TempFile("", "minify-in-*"+ext); err != nil {
+				return err
+			}
+			cmd.Args[i] = arg[:j] + in.Name() + arg[j+3+len(ext):]
+		} else if j := strings.Index(arg, "$out"); j != -1 {
+			var err error
+			ext := cmdArgExtension.FindString(arg[j+4:])
+			if out, err = ioutil.TempFile("", "minify-out-*"+ext); err != nil {
+				return err
+			}
+			cmd.Args[i] = arg[:j] + out.Name() + arg[j+4+len(ext):]
+		}
+	}
+
+	if in == nil {
+		cmd.Stdin = r
+	} else if _, err := io.Copy(in, r); err != nil {
+		return err
+	}
+	if out == nil {
+		cmd.Stdout = w
+	} else {
+		defer io.Copy(w, out)
+	}
+	stderr := &bytes.Buffer{}
+	cmd.Stderr = stderr
+
+	err := cmd.Run()
+	if _, ok := err.(*exec.ExitError); ok {
+		if stderr.Len() != 0 {
+			err = fmt.Errorf("%s", stderr.String())
+		}
+		err = fmt.Errorf("command %s failed: %w", cmd.Path, err)
+	}
+	return err
 }
 
 ////////////////////////////////////////////////////////////////
@@ -159,18 +203,15 @@ func (m *M) MinifyMimetype(mimetype []byte, w io.Writer, r io.Reader, params map
 	m.mutex.RLock()
 	defer m.mutex.RUnlock()
 
-	err := ErrNotExist
 	if minifier, ok := m.literal[string(mimetype)]; ok { // string conversion is optimized away
-		err = minifier.Minify(m, w, r, params)
-	} else {
-		for _, minifier := range m.pattern {
-			if minifier.pattern.Match(mimetype) {
-				err = minifier.Minify(m, w, r, params)
-				break
-			}
+		return minifier.Minify(m, w, r, params)
+	}
+	for _, minifier := range m.pattern {
+		if minifier.pattern.Match(mimetype) {
+			return minifier.Minify(m, w, r, params)
 		}
 	}
-	return err
+	return ErrNotExist
 }
 
 // Bytes minifies an array of bytes (safe for concurrent use). When an error occurs it return the original array and the error.
